@@ -13,8 +13,10 @@ if (suppressMessages(suppressWarnings(require(BEDMatrix)))) {
 
     # only repeat tests where genotypes X is input!
     
-    test_that("function returns precomputed values: get_A", {
-        expect_equal(get_A(X), A)
+    test_that("function returns precomputed values: popkin_A", {
+        expect_silent( obj <- popkin_A( X ) )
+        expect_equal( obj$A, A )
+        expect_equal( obj$M, M )
     })
 
     # higher-level tests now!
